@@ -169,6 +169,9 @@ class Query(Table, Monad):
         
         return res
     
+    def baseTables(self):
+        return self.groupbys.getTables().bind(lambda x: L(x) + x.derivatives)
+    
     def queryTables(self):
         return (self.columns.getTables() + self.groupbys.getTables()).bind(lambda x: L(x) + x.derivatives)
     
